==> daal-devel-2018.0.0.20170814-0.tar.bz2: pydaal_sources/daal/algorithms/neural_networks/layers/loss/forward.py <==
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_forward14', [dirname(__file__)])
        except ImportError:
            import _forward14
            return _forward14
        if fp is not None:
            try:
                _mod = imp.load_module('_forward14', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _forward14 = swig_import_helper()
    del swig_import_helper
else:
    import _forward14
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import daal.algorithms.neural_networks.initializers.uniform
import daal.algorithms.neural_networks.initializers
import daal.algorithms.neural_networks
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import daal.algorithms.neural_networks.layers.backward
import daal.algorithms.neural_networks.layers
import daal.algorithms.neural_networks.layers.forward
import daal.algorithms.engines.mt19937
import daal.algorithms.engines
import daal.algorithms.neural_networks.layers.loss

_forward14.data_swigconstant(_forward14)
data = _forward14.data

_forward14.weights_swigconstant(_forward14)
weights = _forward14.weights

_forward14.biases_swigconstant(_forward14)
biases = _forward14.biases

_forward14.groundTruth_swigconstant(_forward14)
groundTruth = _forward14.groundTruth

_forward14.lastInputId_swigconstant(_forward14)
lastInputId = _forward14.lastInputId
class Input(daal.algorithms.neural_networks.layers.forward.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _forward14.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getforward(self, id):
        return _forward14.Input_getforward(self, id)

    def setInput(self, id, ptr):
        return _forward14.Input_setInput(self, id, ptr)

    def getWeightsSizes(self, parameter):
        return _forward14.Input_getWeightsSizes(self, parameter)

    def getBiasesSizes(self, parameter):
        return _forward14.Input_getBiasesSizes(self, parameter)
    __swig_destroy__ = _forward14.delete_Input
    __del__ = lambda self: None
Input_swigregister = _forward14.Input_swigregister
Input_swigregister(Input)

class Result(daal.algorithms.neural_networks.layers.forward.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _forward14.new_Result()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _forward14.delete_Result
    __del__ = lambda self: None

    def check(self, input, par, method):
        return _forward14.Result_check(self, input, par, method)

    def getValueSize(self, inputSize, par, method):
        return _forward14.Result_getValueSize(self, inputSize, par, method)

    def allocate_Float64(self, input, parameter, method):
        r"""
This function is specialized for float64"""
        return _forward14.Result_allocate_Float64(self, input, parameter, method)


    def allocate_Float32(self, input, parameter, method):
        r"""
This function is specialized for float32"""
        return _forward14.Result_allocate_Float32(self, input, parameter, method)

Result_swigregister = _forward14.Result_swigregister
Result_swigregister(Result)

class Batch(daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def clone(self):
        return _forward14.Batch_clone(self)
    __swig_destroy__ = _forward14.delete_Batch
    __del__ = lambda self: None
Batch_swigregister = _forward14.Batch_swigregister
Batch_swigregister(Batch)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.

==> daal-devel-2020.0-166.tar.bz2: pydaal_sources/daal/algorithms/neural_networks/layers/loss/forward.py <==
# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_forward15_', [dirname(__file__)])
        except ImportError:
            import _forward15_
            return _forward15_
        if fp is not None:
            try:
                _mod = imp.load_module('_forward15_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _forward15_ = swig_import_helper()
    del swig_import_helper
else:
    import _forward15_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.neural_networks.initializers.uniform
import daal.algorithms.neural_networks.initializers
import daal.algorithms.neural_networks
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.features
import daal.data_management.modifiers.csv
import daal.data_management.modifiers
import daal.algorithms.neural_networks.layers.backward
import daal.algorithms.neural_networks.layers
import daal.algorithms.neural_networks.layers.forward
import daal.algorithms.engines.mt19937
import daal.algorithms.engines
import daal.algorithms.neural_networks.layers.loss

_forward15_.data_swigconstant(_forward15_)
data = _forward15_.data

_forward15_.weights_swigconstant(_forward15_)
weights = _forward15_.weights

_forward15_.biases_swigconstant(_forward15_)
biases = _forward15_.biases

_forward15_.groundTruth_swigconstant(_forward15_)
groundTruth = _forward15_.groundTruth

_forward15_.lastInputId_swigconstant(_forward15_)
lastInputId = _forward15_.lastInputId
class Input(daal.algorithms.neural_networks.layers.forward.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _forward15_.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getforward(self, id):
        return _forward15_.Input_getforward(self, id)

    def setInput(self, id, ptr):
        return _forward15_.Input_setInput(self, id, ptr)

    def getWeightsSizes(self, parameter):
        return _forward15_.Input_getWeightsSizes(self, parameter)

    def getBiasesSizes(self, parameter):
        return _forward15_.Input_getBiasesSizes(self, parameter)
    __swig_destroy__ = _forward15_.delete_Input
    __del__ = lambda self: None
Input_swigregister = _forward15_.Input_swigregister
Input_swigregister(Input)

class Result(daal.algorithms.neural_networks.layers.forward.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _forward15_.new_Result()
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _forward15_.delete_Result
    __del__ = lambda self: None

    def check(self, input, par, method):
        return _forward15_.Result_check(self, input, par, method)

    def getValueSize(self, inputSize, par, method):
        return _forward15_.Result_getValueSize(self, inputSize, par, method)

    def allocate_Float64(self, input, parameter, method):
        r"""
    This function is specialized for float64"""
        return _forward15_.Result_allocate_Float64(self, input, parameter, method)


    def allocate_Float32(self, input, parameter, method):
        r"""
    This function is specialized for float32"""
        return _forward15_.Result_allocate_Float32(self, input, parameter, method)

Result_swigregister = _forward15_.Result_swigregister
Result_swigregister(Result)

class Batch(daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.layers.forward.LayerIfaceImpl]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def clone(self):
        return _forward15_.Batch_clone(self)
    __swig_destroy__ = _forward15_.delete_Batch
    __del__ = lambda self: None
Batch_swigregister = _forward15_.Batch_swigregister
Batch_swigregister(Batch)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.
